import { Overmind } from 'overmind';
import { testRender } from './testRender';
import { h, useOvermind } from './';
import { Null } from './Null';
describe('COMPONENT', () => {
    test('should reconcile components', () => {
        const app = new Overmind({});
        const TestCompA = () => h("div", null, "foo");
        const TestCompB = () => h("div", null, "bar");
        const test = testRender(app, h("div", null,
            h(TestCompA, null)));
        const target = test.getTargetElement();
        target.children[0].reconcile(h("div", null,
            h(TestCompB, null)));
        expect(test.getUpdates().length).toBe(10);
        expect(target.children[0].children[0].vtree.children[0].el.nodeValue).toBe('bar');
    });
    test('should reconcile NULL components to component', () => {
        const app = new Overmind({});
        const TestCompA = () => null;
        const TestCompB = () => h("div", null, "bar");
        const test = testRender(app, h("div", null,
            h(TestCompA, null)));
        const target = test.getTargetElement();
        target.children[0].reconcile(h("div", null,
            h(TestCompB, null)));
        expect(test.getUpdates().length).toBe(6);
        expect(target.children[0].children[0].vtree.children[0].el.nodeValue).toBe('bar');
    });
    test('should reconcile components to NULL component', () => {
        const app = new Overmind({});
        const TestCompA = () => h("div", null, "foo");
        const TestCompB = () => null;
        const test = testRender(app, h("div", null,
            h(TestCompA, null)));
        const target = test.getTargetElement();
        target.children[0].reconcile(h("div", null,
            h(TestCompB, null)));
        expect(test.getUpdates().length).toBe(7);
        expect(target.children[0].children[0].vtree).toBeInstanceOf(Null);
    });
    test('should reconcile NULL components to NULL component', () => {
        const app = new Overmind({});
        const TestCompA = () => null;
        const TestCompB = () => null;
        const test = testRender(app, h("div", null,
            h(TestCompA, null)));
        const target = test.getTargetElement();
        target.children[0].reconcile(h("div", null,
            h(TestCompB, null)));
        expect(test.getUpdates().length).toBe(2);
        expect(target.children[0].children[0].vtree).toBeInstanceOf(Null);
    });
    test('should reconcile nested components from within', () => {
        const app = new Overmind({});
        let renderCount = 0;
        const TestCompA = () => (renderCount++ ? h("span", null, "foo") : h("div", null, "bar"));
        const TestCompB = () => h(TestCompA, null);
        const test = testRender(app, h(TestCompB, null));
        const target = test.getTargetElement();
        const testCompA = target.children[0].vtree;
        testCompA.reconcile(testCompA, true);
        expect(test.getUpdates().length).toBe(8);
        expect(target.children[0].vtree.vtree.children[0].el.nodeValue).toBe('foo');
    });
    test('should update on state changes', () => {
        const config = {
            state: {
                foo: true,
            },
            actions: {
                changeFoo({ state }) {
                    state.foo = false;
                },
            },
        };
        const app = new Overmind(config);
        const TestComp = () => {
            const { state } = useOvermind();
            return state.foo ? h("span", null, "foo") : h("div", null, "bar");
        };
        const test = testRender(app, h(TestComp, null));
        const target = test.getTargetElement();
        app.actions.changeFoo();
        expect(test.getUpdates().length).toBe(8);
        expect(target.children[0].vtree.children[0].el.nodeValue).toBe('bar');
    });
});
//# sourceMappingURL=Component.test.js.map