"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const overmind_1 = require("overmind");
const testRender_1 = require("./testRender");
const _1 = require("./");
const Null_1 = require("./Null");
describe('COMPONENT', () => {
    test('should reconcile components', () => {
        const app = new overmind_1.Overmind({});
        const TestCompA = () => _1.h("div", null, "foo");
        const TestCompB = () => _1.h("div", null, "bar");
        const test = testRender_1.testRender(app, _1.h("div", null,
            _1.h(TestCompA, null)));
        const target = test.getTargetElement();
        target.children[0].reconcile(_1.h("div", null,
            _1.h(TestCompB, null)));
        expect(test.getUpdates().length).toBe(10);
        expect(target.children[0].children[0].vtree.children[0].el.nodeValue).toBe('bar');
    });
    test('should reconcile NULL components to component', () => {
        const app = new overmind_1.Overmind({});
        const TestCompA = () => null;
        const TestCompB = () => _1.h("div", null, "bar");
        const test = testRender_1.testRender(app, _1.h("div", null,
            _1.h(TestCompA, null)));
        const target = test.getTargetElement();
        target.children[0].reconcile(_1.h("div", null,
            _1.h(TestCompB, null)));
        expect(test.getUpdates().length).toBe(6);
        expect(target.children[0].children[0].vtree.children[0].el.nodeValue).toBe('bar');
    });
    test('should reconcile components to NULL component', () => {
        const app = new overmind_1.Overmind({});
        const TestCompA = () => _1.h("div", null, "foo");
        const TestCompB = () => null;
        const test = testRender_1.testRender(app, _1.h("div", null,
            _1.h(TestCompA, null)));
        const target = test.getTargetElement();
        target.children[0].reconcile(_1.h("div", null,
            _1.h(TestCompB, null)));
        expect(test.getUpdates().length).toBe(7);
        expect(target.children[0].children[0].vtree).toBeInstanceOf(Null_1.Null);
    });
    test('should reconcile NULL components to NULL component', () => {
        const app = new overmind_1.Overmind({});
        const TestCompA = () => null;
        const TestCompB = () => null;
        const test = testRender_1.testRender(app, _1.h("div", null,
            _1.h(TestCompA, null)));
        const target = test.getTargetElement();
        target.children[0].reconcile(_1.h("div", null,
            _1.h(TestCompB, null)));
        expect(test.getUpdates().length).toBe(2);
        expect(target.children[0].children[0].vtree).toBeInstanceOf(Null_1.Null);
    });
    test('should reconcile nested components from within', () => {
        const app = new overmind_1.Overmind({});
        let renderCount = 0;
        const TestCompA = () => (renderCount++ ? _1.h("span", null, "foo") : _1.h("div", null, "bar"));
        const TestCompB = () => _1.h(TestCompA, null);
        const test = testRender_1.testRender(app, _1.h(TestCompB, null));
        const target = test.getTargetElement();
        const testCompA = target.children[0].vtree;
        testCompA.reconcile(testCompA, true);
        expect(test.getUpdates().length).toBe(8);
        expect(target.children[0].vtree.vtree.children[0].el.nodeValue).toBe('foo');
    });
    test('should update on state changes', () => {
        const config = {
            state: {
                foo: true,
            },
            actions: {
                changeFoo({ state }) {
                    state.foo = false;
                },
            },
        };
        const app = new overmind_1.Overmind(config);
        const TestComp = () => {
            const { state } = _1.useOvermind();
            return state.foo ? _1.h("span", null, "foo") : _1.h("div", null, "bar");
        };
        const test = testRender_1.testRender(app, _1.h(TestComp, null));
        const target = test.getTargetElement();
        app.actions.changeFoo();
        expect(test.getUpdates().length).toBe(8);
        expect(target.children[0].vtree.children[0].el.nodeValue).toBe('bar');
    });
});
//# sourceMappingURL=Component.test.js.map