"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const overmind_1 = require("overmind");
const testRender_1 = require("./testRender");
const _1 = require("./");
describe('ELEMENT', () => {
    describe('KEYS', () => {
        test('should render keyed children', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo"),
                _1.h("li", { key: "bar" }, "bar")));
            const target = test.getTargetElement();
            expect(test.getUpdates().length).toBe(10);
            expect(target.children[0].children.length).toBe(2);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('bar');
        });
        test('should reconcile removing last keyed child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo"),
                _1.h("li", { key: "bar" }, "bar")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", null, "foo")));
            expect(test.getUpdates().length).toBe(11);
            expect(target.children[0].children.length).toBe(1);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
        });
        test('should reconcile removing first child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo"),
                _1.h("li", { key: "bar" }, "bar")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", { key: "bar" }, "bar")));
            expect(test.getUpdates().length).toBe(12);
            expect(test.getUpdates()[10].type).toBe('replaceChild');
            expect(target.children[0].children.length).toBe(1);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('bar');
        });
        test('should reconcile removing in between keyed children', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo"),
                _1.h("li", { key: "bar" }, "bar"),
                _1.h("li", { key: "baz" }, "baz")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo"),
                _1.h("li", { key: "baz" }, "baz")));
            expect(test.getUpdates().length).toBe(16);
            expect(test.getUpdates()[14].type).toBe('replaceChild');
            expect(target.children[0].children.length).toBe(2);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('baz');
        });
        test('should reconcile prepending child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", { key: "bar" }, "bar"),
                _1.h("li", { key: "foo" }, "foo")));
            expect(test.getUpdates().length).toBe(11);
            expect(target.children[0].children.length).toBe(2);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('bar');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('foo');
        });
        test('should reconcile appending child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo"),
                _1.h("li", { key: "bar" }, "bar")));
            expect(test.getUpdates().length).toBe(10);
            expect(target.children[0].children.length).toBe(2);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('bar');
        });
        test('should reconcile appending in between child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo"),
                _1.h("li", { key: "baz" }, "baz")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", { key: "foo" }, "foo"),
                _1.h("li", { key: "bar" }, "bar"),
                _1.h("li", { key: "baz" }, "baz")));
            expect(test.getUpdates().length).toBe(15);
            expect(target.children[0].children.length).toBe(3);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('bar');
            expect(target.children[0].children[2].children[0].el.nodeValue).toBe('baz');
        });
    });
    describe('CHILDREN', () => {
        test('should render children', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h("li", null, "bar")));
            const target = test.getTargetElement();
            expect(test.getUpdates().length).toBe(10);
            expect(target.children[0].children.length).toBe(2);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('bar');
        });
        test('should reconcile removing last child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h("li", null, "bar")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", null, "foo")));
            expect(test.getUpdates().length).toBe(11);
            expect(target.children[0].children.length).toBe(1);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
        });
        test('should reconcile removing first child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h("li", null, "bar")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", null, "bar")));
            expect(test.getUpdates().length).toBe(12);
            expect(test.getUpdates()[10].type).toBe('nodeValue');
            expect(target.children[0].children.length).toBe(1);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('bar');
        });
        test('should reconcile removing in between child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h("li", null, "bar"),
                _1.h("li", null, "baz")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h("li", null, "baz")));
            expect(test.getUpdates().length).toBe(16);
            expect(target.children[0].children.length).toBe(2);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('baz');
        });
        test('should reconcile prepending child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", null, "foo")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", null, "bar"),
                _1.h("li", null, "foo")));
            expect(test.getUpdates().length).toBe(11);
            expect(target.children[0].children.length).toBe(2);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('bar');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('foo');
        });
        test('should reconcile appending child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", null, "foo")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h("li", null, "bar")));
            expect(test.getUpdates().length).toBe(10);
            expect(target.children[0].children.length).toBe(2);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('bar');
        });
        test('should reconcile appending in between child', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h("li", null, "baz")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h("li", null, "bar"),
                _1.h("li", null, "baz")));
            expect(test.getUpdates().length).toBe(15);
            expect(target.children[0].children.length).toBe(3);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
            expect(target.children[0].children[1].children[0].el.nodeValue).toBe('bar');
            expect(target.children[0].children[2].children[0].el.nodeValue).toBe('baz');
        });
        test('should reconcile appending in between child where new child is NULL', () => {
            const app = new overmind_1.Overmind({});
            const TestComponent = () => null;
            const test = testRender_1.testRender(app, _1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h("li", null, "baz")));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("ul", null,
                _1.h("li", null, "foo"),
                _1.h(TestComponent, null),
                _1.h("li", null, "baz")));
            expect(test.getUpdates().length).toBe(15);
            expect(target.children[0].children.length).toBe(3);
            expect(target.children[0].children[0].children[0].el.nodeValue).toBe('foo');
            expect(target.children[0].children[2].children[0].el.nodeValue).toBe('baz');
        });
    });
    describe('ATTRIBUTES', () => {
        test('should reconcile CLASSNAME', () => {
            const app = new overmind_1.Overmind({});
            const test = testRender_1.testRender(app, _1.h("div", null));
            const target = test.getTargetElement();
            target.children[0].reconcile(_1.h("div", { className: "foo" }));
            expect(test.getUpdates().length).toBe(3);
            expect(target.children[0].el.attrs).toEqual({
                class: 'foo',
            });
        });
    });
});
//# sourceMappingURL=Element.test.js.map