"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const overmind_1 = require("overmind");
const testRender_1 = require("./testRender");
const _1 = require("./");
const Literal_1 = require("./Literal");
const Null_1 = require("./Null");
describe('LITERAL', () => {
    test('should reconcile literals', () => {
        const app = new overmind_1.Overmind({});
        const test = testRender_1.testRender(app, _1.h("div", null, "foo"));
        const foo = test.getTargetElement().children[0].children[0];
        foo.reconcile(new Literal_1.Literal('bar'));
        expect(foo.value).toBe('bar');
    });
    test('should reconcile element literal children', () => {
        const app = new overmind_1.Overmind({});
        const test = testRender_1.testRender(app, _1.h("div", null, "foo"));
        const target = test.getTargetElement();
        target.children[0].reconcile(_1.h("div", null, "bar"));
        const foo = target.children[0].children[0];
        expect(foo.value).toBe('bar');
        expect(foo.el.nodeValue).toBe('bar');
    });
    test('should reconcile NULL to literal', () => {
        const app = new overmind_1.Overmind({});
        const test = testRender_1.testRender(app, _1.h("div", null, null));
        const target = test.getTargetElement();
        target.children[0].reconcile(_1.h("div", null, "foo"));
        const foo = target.children[0].children[0];
        expect(test.getUpdates().length).toBe(4);
        expect(foo.value).toBe('foo');
        expect(foo.el.nodeValue).toBe('foo');
    });
    test('should reconcile literal to NULL', () => {
        const app = new overmind_1.Overmind({});
        const test = testRender_1.testRender(app, _1.h("div", null, "foo"));
        const target = test.getTargetElement();
        target.children[0].reconcile(_1.h("div", null, null));
        const foo = target.children[0].children[0];
        expect(test.getUpdates().length).toBe(5);
        expect(foo).toBeInstanceOf(Null_1.Null);
    });
    test('should reconcile NULL to literal to nearest element', () => {
        const app = new overmind_1.Overmind({});
        const test = testRender_1.testRender(app, _1.h("div", null,
            "foo",
            null,
            null,
            null,
            "baz"));
        test.getTargetElement().children[0].reconcile(_1.h("div", null,
            "foo",
            null,
            "bar",
            null,
            "baz"));
        expect(test.getUpdates()[7].args[1].nodeValue).toBe('baz');
        expect(test.getUpdates().length).toBe(8);
    });
});
//# sourceMappingURL=Literal.test.js.map