"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Component_1 = require("./Component");
function useOvermind() {
    const component = Component_1.Component.current;
    const existingHook = component.getHook();
    if (existingHook) {
        component.nextHookIndex++;
        return existingHook;
    }
    const hook = {
        state: component.context.app.state,
        actions: component.context.app.actions,
    };
    component.addHook(hook);
    return hook;
}
exports.useOvermind = useOvermind;
function useState(initialState) {
    const component = Component_1.Component.current;
    const existingHook = component.getHook();
    if (existingHook) {
        component.nextHookIndex++;
        return existingHook;
    }
    const hook = [
        initialState,
        (newState) => {
            hook[0] = newState;
            component.reconcile(component, true);
        },
    ];
    component.addHook(hook);
    return hook;
}
exports.useState = useState;
function useEffect(effect, mem) {
    const component = Component_1.Component.current;
    const existingHook = component.getHook();
    if (existingHook) {
        existingHook.unsubscribe && existingHook.unsubscribe();
        component.mountListeners.delete(existingHook.updateListener);
        component.reconcileListeners.delete(existingHook.updateListener);
        component.unmountListeners.delete(existingHook.unmountListener);
    }
    const hook = {
        unsubscribe: () => { },
        updateListener: existingHook && mem
            ? () => {
                if (mem.reduce((aggr, val, index) => aggr ? val === existingHook.mem[index] : false, true)) {
                    return;
                }
                hook.unsubscribe = effect();
            }
            : () => {
                hook.unsubscribe = effect();
            },
        unmountListener: () => {
            hook.unsubscribe && hook.unsubscribe();
        },
        mem,
    };
    component.mountListeners.add(hook.updateListener);
    component.reconcileListeners.add(hook.updateListener);
    component.unmountListeners.add(hook.unmountListener);
    component.addHook(hook);
}
exports.useEffect = useEffect;
function useRef() {
    const existingHook = Component_1.Component.current.getHook();
    if (existingHook) {
        Component_1.Component.current.nextHookIndex++;
        return existingHook;
    }
    let hook = (node) => {
        ;
        hook.current = node;
    };
    Component_1.Component.current.addHook(hook);
    return hook;
}
exports.useRef = useRef;
//# sourceMappingURL=hooks.js.map