"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Component_1 = require("./Component");
const Element_1 = require("./Element");
const Null_1 = require("./Null");
const Literal_1 = require("./Literal");
const Events_1 = require("./Events");
tslib_1.__exportStar(require("./hooks"), exports);
function evaluateChildren(children) {
    return children.reduce((aggr, child) => {
        if (child === null) {
            return aggr.concat(new Null_1.Null());
        }
        else if (typeof child !== 'object' && typeof child !== 'function') {
            return aggr.concat(new Literal_1.Literal(child));
        }
        else if (Array.isArray(child)) {
            return aggr.concat(child.map((subChild) => {
                if (subChild === null) {
                    return new Null_1.Null();
                }
                else if (typeof subChild !== 'object' &&
                    typeof subChild !== 'function') {
                    return new Literal_1.Literal(subChild);
                }
                return subChild;
            }));
        }
        return aggr.concat(child);
    }, []);
}
function createElement(tag, props, ...children) {
    if (typeof tag === 'function') {
        return new Component_1.Component(tag, props, evaluateChildren(children));
    }
    return new Element_1.Element(tag, props, evaluateChildren(children));
}
exports.createElement = createElement;
exports.h = createElement;
function render(app, source, target, factory = document) {
    app.nextComponentId = 0;
    const parent = new Element_1.Element(target, null, [source]);
    parent.mount(null, {
        app,
        factory,
        events: new Events_1.Events(factory),
    });
    return parent;
}
exports.render = render;
//# sourceMappingURL=index.js.map