"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const overmind_1 = require("overmind");
const testRender_1 = require("./testRender");
const _1 = require("./");
const Null_1 = require("./Null");
describe('RENDER', () => {
    test.only('should create element', () => {
        const app = new overmind_1.Overmind({});
        const test = testRender_1.testRender(app, _1.h("div", null));
        const updates = test.getUpdates();
        expect(updates.length).toBe(2);
        expect(updates[0]).toEqual({
            type: 'createElement',
            args: ['div'],
        });
    });
    test('should create nested element', () => {
        const app = new overmind_1.Overmind({});
        const test = testRender_1.testRender(app, _1.h("div", null,
            _1.h("span", null)));
        const updates = test.getUpdates();
        expect(updates[0]).toEqual({
            type: 'createElement',
            args: ['div'],
        });
        expect(updates[1]).toEqual({
            type: 'createElement',
            args: ['span'],
        });
        expect(updates[2].type).toBe('appendChild');
        const el = test.getTargetElement();
        expect(el.children[0].tag).toBe('div');
        expect(el.children[0].children[0].tag).toBe('span');
    });
    test('should render component', () => {
        const app = new overmind_1.Overmind({});
        const TestComp = () => {
            return _1.h("div", null);
        };
        const test = testRender_1.testRender(app, _1.h(TestComp, null));
        const updates = test.getUpdates();
        expect(updates[0]).toEqual({
            type: 'createElement',
            args: ['div'],
        });
        const el = test.getTargetElement();
        expect(el.children[0].tag).toBe(TestComp);
        expect(el.children[0].vtree.tag).toBe('div');
    });
    test('should render NULL component', () => {
        const app = new overmind_1.Overmind({});
        const TestComp = () => {
            return null;
        };
        const test = testRender_1.testRender(app, _1.h(TestComp, null));
        const updates = test.getUpdates();
        expect(updates.length).toBe(0);
        const el = test.getTargetElement();
        expect(el.children[0].tag).toBe(TestComp);
        expect(el.children[0].vtree).toBeInstanceOf(Null_1.Null);
    });
});
//# sourceMappingURL=render.test.js.map